@@ -26,6 +26,8 @@ module Xmobar (xmobar
               , SignalType (..)
               , module Xmobar.Config.Types
               , module Xmobar.Config.Parse
+              , module Xmobar.Plugins.Accordion
+              , module Xmobar.Plugins.ArchUpdates
               , module Xmobar.Plugins.BufferedPipeReader
               , module Xmobar.Plugins.CommandReader
               , module Xmobar.Plugins.Date
@@ -43,6 +45,7 @@ module Xmobar (xmobar
 #endif
               , module Xmobar.Plugins.NotmuchMail
               , module Xmobar.Plugins.Monitors
+              , module Xmobar.Plugins.PacmanUpdates
               , module Xmobar.Plugins.PipeReader
               , module Xmobar.Plugins.MarqueePipeReader
               , module Xmobar.Plugins.StdinReader
@@ -53,6 +56,8 @@ import Xmobar.Run.Runnable
 import Xmobar.Run.Exec
 import Xmobar.Config.Types
 import Xmobar.Config.Parse
+import Xmobar.Plugins.Accordion
+import Xmobar.Plugins.ArchUpdates
 import Xmobar.Plugins.Command
 import Xmobar.Plugins.BufferedPipeReader
 import Xmobar.Plugins.CommandReader
@@ -70,6 +75,7 @@ import Xmobar.Plugins.Mail
 import Xmobar.Plugins.MBox
 #endif
 import Xmobar.Plugins.Monitors
+import Xmobar.Plugins.PacmanUpdates
 import Xmobar.Plugins.PipeReader
 import Xmobar.Plugins.StdinReader
 import Xmobar.Plugins.MarqueePipeReader
