@@ -109,8 +109,9 @@ parseMPD (Right st) song opts = do
         si = stateGlyph s opts
         vol = int2str $ fromMaybe 0 (M.stVolume st)
         (p, t) = fromMaybe (0, 0) (M.stTime st)
-        [lap, len, remain] = map showTime
-                                 [floor p, floor t, max 0 (floor t - floor p)]
+        lap = showTime $ floor p
+        len = showTime $ floor t
+        remain = showTime $ max 0 (floor t - floor p)
         b = if t > 0 then realToFrac $ p / t else 0
         plen = int2str $ M.stPlaylistLength st
         ppos = maybe "" (int2str . (+1)) $ M.stSongPos st
